Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(184)

Unified Diff: chromeos/printing/ppd_provider.h

Issue 2814633002: Add CupsFilter extraction from resolved ppds for printing. (Closed)
Patch Set: Fix lint nit Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chromeos/printing/ppd_provider.h
diff --git a/chromeos/printing/ppd_provider.h b/chromeos/printing/ppd_provider.h
index 0b378357c48a44b5d3bb161bd04031163bc0b7c8..ebfd22b6e2fb8324ff9fd5c1363e8e29ece1af7d 100644
--- a/chromeos/printing/ppd_provider.h
+++ b/chromeos/printing/ppd_provider.h
@@ -57,11 +57,15 @@ class CHROMEOS_EXPORT PpdProvider : public base::RefCounted<PpdProvider> {
std::string ppd_server_root = "https://www.gstatic.com/chromeos_printing";
};
// Result of a ResolvePpd() call. If the result code is SUCCESS, then the
// string holds the contents of a PPD (that may or may not be gzipped).
// Otherwise, the string will be empty.
skau 2017/04/11 16:59:37 theses
Carlson 2017/04/11 19:06:49 Done.
using ResolvePpdCallback =
- base::Callback<void(CallbackResultCode, const std::string&)>;
+ base::Callback<void(CallbackResultCode,
+ const std::string&,
+ const std::vector<std::string>& required_filters)>;
// Result of a ResolveManufacturers() call. If the result code is SUCCESS,
// then the vector contains a sorted list of manufacturers for which we have
@@ -57,11 +57,15 @@ class CHROMEOS_EXPORT PpdProvider : public base::RefCounted<PpdProvider> {
std::string ppd_server_root = "https://www.gstatic.com/chromeos_printing";
};
- // Result of a ResolvePpd() call. If the result code is SUCCESS, then the
- // string holds the contents of a PPD (that may or may not be gzipped).
- // Otherwise, the string will be empty.
+ // Result of a ResolvePpd() call.
+ // If the result code is SUCCESS, then:
+ // string holds the contents of a PPD (that may or may not be gzipped).
+ // required_filters holds the names of the filters referenced in the ppd.
+ // Otherwise, theses fields will be empty.
skau 2017/04/11 16:59:37 theses
Carlson 2017/04/11 19:06:49 Done.

Powered by Google App Engine
This is Rietveld 408576698